@@ -1,3 +1,5 @@
+from typing import Optional
+
 import cv2
 import numpy as np
 
@@ -6,11 +8,21 @@ from metaseg.utils.file import download_model
 
 
 class SegAutoMaskGenerator:
-    def __init__(self, model_type, source, device, show):
+    def __init__(
+        self,
+        model_type: str = "vit_h",
+        source: str = "test.jpg",
+        device: str = "cuda",
+        show: bool = True,
+        points_per_side: Optional[int] = 16,
+        points_per_batch: Optional[int] = 64,
+    ):
         self.model_type = model_type
         self.device = device
         self.source = source
         self.model = None
+        self.points_per_side = points_per_side
+        self.points_per_batch = points_per_batch
 
         if show:
             if source.endswith(".mp4"):
@@ -39,15 +51,17 @@ class SegAutoMaskGenerator:
         cap = cv2.VideoCapture(self.source)
         frame_width = int(cap.get(cv2.CAP_PROP_FRAME_WIDTH))
         frame_height = int(cap.get(cv2.CAP_PROP_FRAME_HEIGHT))
-        fourcc = cv2.VideoWriter_fourcc(*"XVID")  # Kaydedilecek video codec'i
-        fps = int(cap.get(cv2.CAP_PROP_FPS))  # Orjinal videonun FPS'i
+        fourcc = cv2.VideoWriter_fourcc(*"XVID")
+        fps = int(cap.get(cv2.CAP_PROP_FPS))
         out = cv2.VideoWriter("outv1.mp4", fourcc, fps, (frame_width, frame_height))
 
         return cap, out
 
     def predict(self, frame):
         model = self.load_model()
-        mask_generator = SamAutomaticMaskGenerator(model, points_per_side=16, points_per_batch=32)
+        mask_generator = SamAutomaticMaskGenerator(
+            model, points_per_side=self.points_per_side, points_per_batch=self.points_per_batch
+        )
         masks = mask_generator.generate(frame)
 
         return frame, masks
@@ -74,7 +88,7 @@ class SegAutoMaskGenerator:
             mask_image = cv2.add(mask_image, img)
 
         combined_mask = cv2.add(image, mask_image)
-        cv2.imwrite("new3.jpg", combined_mask)
+        cv2.imshow("Output", combined_mask)
         cv2.waitKey(0)
         cv2.destroyAllWindows()
 
